@@ -279,37 +279,6 @@ set_legacy_ibus_env_vars (GDBusProxy *proxy)
 }
 #endif
 
-/* Keep synchronised with set_locale() and
- * set_legacy_ibus_env_vars() above */
-static void
-set_locale_env (void)
-{
-        GSettings *locale_settings;
-        gchar *region;
-
-        /* Set locale environment */
-        locale_settings = g_settings_new ("org.gnome.system.locale");
-        region = g_settings_get_string (locale_settings, "region");
-        if (region[0]) {
-                g_setenv ("LC_TIME", region, TRUE);
-                g_setenv ("LC_NUMERIC", region, TRUE);
-                g_setenv ("LC_MONETARY", region, TRUE);
-                g_setenv ("LC_MEASUREMENT", region, TRUE);
-                g_setenv ("LC_PAPER", region, TRUE);
-        }
-        g_free (region);
-        g_object_unref (locale_settings);
-
-#ifdef HAVE_IBUS
-        /* Set IBus legacy environment */
-        if (is_program_in_path ("ibus-daemon") &&
-            keyboard_plugin_is_enabled ()) {
-                g_setenv ("QT_IM_MODULE", "ibus", TRUE);
-                g_setenv ("XMODIFIERS", "@im=ibus", TRUE);
-        }
-#endif
-}
-
 static void
 register_with_gnome_session (GDBusProxy *proxy)
 {
@@ -499,8 +468,6 @@ main (int argc, char *argv[])
 
         g_log_set_default_handler (gsd_log_default_handler, NULL);
 
-        set_locale_env ();
-
         notify_init ("gnome-settings-daemon");
 
         bus_register ();
